parse_annotated_time_record

Function parse_annotated_time_record 

pub(crate) fn parse_annotated_time_record<'a, T: EncodingType>(
    cursor: &mut Cursor<'a, T>,
    handler: impl FnMut(Annotation<'a, T>) -> Option<Annotation<'a, T>>,
) -> ParserResult<IxdtfParseRecord<'a, T>>
Parse annotated time record is silently fallible returning None in the case that the value does not align